@@ -14,22 +14,24 @@ textual console -v
 from __future__ import annotations
 
 from dataclasses import dataclass
+from pathlib import Path
 from typing import TYPE_CHECKING, Type, TypeVar
 
 import rich.repr
 from rich.style import Style
 
-from ._types import CallbackType
-from .geometry import Offset, Size
-from .keys import _get_key_aliases
-from .message import Message
+from textual._types import CallbackType
+from textual.geometry import Offset, Size
+from textual.keys import _get_key_aliases
+from textual.message import Message
 
 MouseEventT = TypeVar("MouseEventT", bound="MouseEvent")
 
 if TYPE_CHECKING:
-    from .timer import Timer as TimerClass
-    from .timer import TimerCallback
-    from .widget import Widget
+    from textual.dom import DOMNode
+    from textual.timer import Timer as TimerClass
+    from textual.timer import TimerCallback
+    from textual.widget import Widget
 
 
 @rich.repr.auto
@@ -39,6 +41,11 @@ class Event(Message):
 
 @rich.repr.auto
 class Callback(Event, bubble=False, verbose=True):
+    """Sent by Textual to invoke a callback
+    (see [call_next][textual.message_pump.MessagePump.call_next] and
+    [call_later][textual.message_pump.MessagePump.call_later]).
+    """
+
     def __init__(self, callback: CallbackType) -> None:
         self.callback = callback
         super().__init__()
@@ -47,14 +54,6 @@ class Callback(Event, bubble=False, verbose=True):
         yield "callback", self.callback
 
 
-class ShutdownRequest(Event):
-    pass
-
-
-class Shutdown(Event):
-    pass
-
-
 @dataclass
 class CursorPosition(Event, bubble=False):
     """Internal event used to retrieve the terminal's cursor position."""
@@ -116,6 +115,7 @@ class Resize(Event, bubble=False):
         size: Size,
         virtual_size: Size,
         container_size: Size | None = None,
+        pixel_size: Size | None = None,
     ) -> None:
         self.size = size
         """The new size of the Widget."""
@@ -123,15 +123,33 @@ class Resize(Event, bubble=False):
         """The virtual size (scrollable size) of the Widget."""
         self.container_size = size if container_size is None else container_size
         """The size of the Widget's container widget."""
+        self.pixel_size = pixel_size
+        """Size of terminal window in pixels if known, or `None` if not known."""
         super().__init__()
 
+    @classmethod
+    def from_dimensions(
+        cls, cells: tuple[int, int], pixels: tuple[int, int] | None
+    ) -> Resize:
+        """Construct from basic dimensions.
+
+        Args:
+            cells: tuple of (<width>, <height>) in cells.
+            pixels: tuple of (<width>, <height>) in pixels if known, or `None` if not known.
+
+        """
+        size = Size(*cells)
+        pixel_size = Size(*pixels) if pixels is not None else None
+        return Resize(size, size, size, pixel_size)
+
     def can_replace(self, message: "Message") -> bool:
         return isinstance(message, Resize)
 
     def __rich_repr__(self) -> rich.repr.Result:
         yield "size", self.size
-        yield "virtual_size", self.virtual_size
+        yield "virtual_size", self.virtual_size, self.size
         yield "container_size", self.container_size, self.size
+        yield "pixel_size", self.pixel_size, None
 
 
 class Compose(Event, bubble=False, verbose=True):
@@ -292,8 +310,12 @@ class Key(InputEvent):
 
 def _key_to_identifier(key: str) -> str:
     """Convert the key string to a name suitable for use as a Python identifier."""
-    if len(key) == 1 and key.isupper():
-        key = f"upper_{key.lower()}"
+    key_no_modifiers = key.split("+")[-1]
+    if len(key_no_modifiers) == 1 and key_no_modifiers.isupper():
+        if "+" in key:
+            key = f"{key.rpartition('+')[0]}+upper_{key_no_modifiers}"
+        else:
+            key = f"upper_{key_no_modifiers}"
     return key.replace("+", "_").lower()
 
 
@@ -305,6 +327,7 @@ class MouseEvent(InputEvent, bubble=True):
     - [ ] Verbose
 
     Args:
+        widget: The widget under the mouse.
         x: The relative x coordinate.
         y: The relative y coordinate.
         delta_x: Change in x since the last message.
@@ -319,6 +342,7 @@ class MouseEvent(InputEvent, bubble=True):
     """
 
     __slots__ = [
+        "widget",
         "x",
         "y",
         "delta_x",
@@ -334,6 +358,7 @@ class MouseEvent(InputEvent, bubble=True):
 
     def __init__(
         self,
+        widget: Widget | None,
         x: int,
         y: int,
         delta_x: int,
@@ -347,6 +372,8 @@ class MouseEvent(InputEvent, bubble=True):
         style: Style | None = None,
     ) -> None:
         super().__init__()
+        self.widget: Widget | None = widget
+        """The widget under the mouse at the time of a click."""
         self.x = x
         """The relative x coordinate."""
         self.y = y
@@ -370,8 +397,11 @@ class MouseEvent(InputEvent, bubble=True):
         self._style = style or Style()
 
     @classmethod
-    def from_event(cls: Type[MouseEventT], event: MouseEvent) -> MouseEventT:
+    def from_event(
+        cls: Type[MouseEventT], widget: Widget, event: MouseEvent
+    ) -> MouseEventT:
         new_event = cls(
+            widget,
             event.x,
             event.y,
             event.delta_x,
@@ -387,6 +417,7 @@ class MouseEvent(InputEvent, bubble=True):
         return new_event
 
     def __rich_repr__(self) -> rich.repr.Result:
+        yield self.widget
         yield "x", self.x
         yield "y", self.y
         yield "delta_x", self.delta_x, 0
@@ -400,6 +431,10 @@ class MouseEvent(InputEvent, bubble=True):
         yield "meta", self.meta, False
         yield "ctrl", self.ctrl, False
 
+    @property
+    def control(self) -> Widget | None:
+        return self.widget
+
     @property
     def offset(self) -> Offset:
         """The mouse coordinate as an offset.
@@ -456,6 +491,7 @@ class MouseEvent(InputEvent, bubble=True):
 
     def _apply_offset(self, x: int, y: int) -> MouseEvent:
         return self.__class__(
+            self.widget,
             x=self.x + x,
             y=self.y + y,
             delta_x=self.delta_x,
@@ -551,21 +587,54 @@ class Timer(Event, bubble=False, verbose=True):
         yield "count", self.count
 
 
-class Enter(Event, bubble=False, verbose=True):
+class Enter(Event, bubble=True, verbose=True):
     """Sent when the mouse is moved over a widget.
 
-    - [ ] Bubbles
+    Note that this event bubbles, so a widget may receive this event when the mouse
+    moves over a child widget. Check the `node` attribute for the widget directly under
+    the mouse.
+
+    - [X] Bubbles
     - [X] Verbose
     """
 
+    __slots__ = ["node"]
 
-class Leave(Event, bubble=False, verbose=True):
-    """Sent when the mouse is moved away from a widget.
+    def __init__(self, node: DOMNode) -> None:
+        self.node = node
+        """The node directly under the mouse."""
+        super().__init__()
 
-    - [ ] Bubbles
+    @property
+    def control(self) -> DOMNode:
+        """Alias for the `node` under the mouse."""
+        return self.node
+
+
+class Leave(Event, bubble=True, verbose=True):
+    """Sent when the mouse is moved away from a widget, or if a widget is
+    programmatically disabled while hovered.
+
+    Note that this widget bubbles, so a widget may receive Leave events for any child widgets.
+    Check the `node` parameter for the original widget that was previously under the mouse.
+
+
+    - [X] Bubbles
     - [X] Verbose
     """
 
+    __slots__ = ["node"]
+
+    def __init__(self, node: DOMNode) -> None:
+        self.node = node
+        """The node that was previously directly under the mouse."""
+        super().__init__()
+
+    @property
+    def control(self) -> DOMNode:
+        """Alias for the `node` that was previously under the mouse."""
+        return self.node
+
 
 class Focus(Event, bubble=False):
     """Sent when a widget is focussed.
@@ -707,3 +776,36 @@ class Print(Event, bubble=False):
     def __rich_repr__(self) -> rich.repr.Result:
         yield self.text
         yield self.stderr
+
+
+@dataclass
+class DeliveryComplete(Event, bubble=False):
+    """Sent to App when a file has been delivered."""
+
+    key: str
+    """The delivery key associated with the delivery.
+    
+    This is the same key that was returned by `App.deliver_text`/`App.deliver_binary`.
+    """
+
+    path: Path | None = None
+    """The path where the file was saved, or `None` if the path is not available, for
+    example if the file was delivered via web browser.
+    """
+
+    name: str | None = None
+    """Optional name returned to the app to identify the download."""
+
+
+@dataclass
+class DeliveryFailed(Event, bubble=False):
+    """Sent to App when a file delivery fails."""
+
+    key: str
+    """The delivery key associated with the delivery."""
+
+    exception: BaseException
+    """The exception that was raised during the delivery."""
+
+    name: str | None = None
+    """Optional name returned to the app to identify the download."""
