@@ -7,18 +7,19 @@ import rich.repr
 from rich.console import RenderableType
 from rich.text import Text
 
-from .. import events, on
-from ..containers import Horizontal, Vertical
-from ..css.query import NoMatches
-from ..message import Message
-from ..reactive import var
-from ..widgets import Static
-from ._option_list import Option, OptionList
+from textual import events, on
+from textual.binding import Binding
+from textual.containers import Horizontal, Vertical
+from textual.css.query import NoMatches
+from textual.message import Message
+from textual.reactive import var
+from textual.widgets import Static
+from textual.widgets._option_list import Option, OptionList
 
 if TYPE_CHECKING:
     from typing_extensions import TypeAlias
 
-    from ..app import ComposeResult
+    from textual.app import ComposeResult
 
 
 class NoSelection:
@@ -42,23 +43,7 @@ class EmptySelectError(Exception):
 class SelectOverlay(OptionList):
     """The 'pop-up' overlay for the Select control."""
 
-    BINDINGS = [("escape", "dismiss")]
-
-    DEFAULT_CSS = """
-    SelectOverlay {
-        border: tall $background;
-        background: $panel;
-        color: $text;
-        width: 100%;
-        padding: 0 1;
-    }
-    SelectOverlay:focus {
-        border: tall $background;
-    }
-    SelectOverlay > .option-list--option {
-        padding: 0 1;
-    }
-    """
+    BINDINGS = [("escape", "dismiss", "Dismiss menu")]
 
     @dataclass
     class Dismiss(Message):
@@ -90,6 +75,7 @@ class SelectOverlay(OptionList):
     def _on_blur(self, _event: events.Blur) -> None:
         """On blur we want to dismiss the overlay."""
         self.post_message(self.Dismiss(lost_focus=True))
+        self.suppress_click()
 
     def on_option_list_option_selected(self, event: OptionList.OptionSelected) -> None:
         """Inform parent when an option is selected."""
@@ -108,22 +94,28 @@ class SelectCurrent(Horizontal):
 
     DEFAULT_CSS = """
     SelectCurrent {
-        border: tall transparent;
-        background: $boost;
-        color: $text;
-        width: 100%;
+        border: tall $border-blurred;
+        color: $foreground;
+        background: $surface;
+        width: 1fr;
         height: auto;
         padding: 0 2;
 
+        &:ansi {
+            border: tall ansi_blue;
+            color: ansi_default;
+            background: ansi_default;
+        }
+
         Static#label {
             width: 1fr;
             height: auto;
-            color: $text-disabled;
+            color: $foreground 50%;
             background: transparent;
         }
 
         &.-has-value Static#label {
-            color: $text;
+            color: $foreground;
         }
 
         .arrow {
@@ -131,7 +123,7 @@ class SelectCurrent(Horizontal):
             width: 1;
             height: 1;
             padding: 0 0 0 1;
-            color: $text-muted;
+            color: $foreground 50%;
             background: transparent;
         }
     }
@@ -175,8 +167,9 @@ class SelectCurrent(Horizontal):
         """Toggle the class."""
         self.set_class(has_value, "-has-value")
 
-    async def _on_click(self, event: events.Click) -> None:
+    def _on_click(self, event: events.Click) -> None:
         """Inform ancestor we want to toggle."""
+        event.stop()
         self.post_message(self.Toggle())
 
 
@@ -196,7 +189,9 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
     BLANK = BLANK
     """Constant to flag that the widget has no selection."""
 
-    BINDINGS = [("enter,down,space,up", "show_overlay")]
+    BINDINGS = [
+        Binding("enter,down,space,up", "show_overlay", "Show menu", show=False),
+    ]
     """
     | Key(s) | Description |
     | :- | :- |
@@ -206,6 +201,16 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
     DEFAULT_CSS = """
     Select {
         height: auto;
+        color: $foreground;
+        
+        .up-arrow {
+            display: none;
+        }
+
+        &:focus > SelectCurrent {
+            border: tall $border;
+            background-tint: $foreground 5%;
+        }
 
         & > SelectOverlay {
             width: 1fr;
@@ -213,32 +218,32 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
             height: auto;
             max-height: 12;
             overlay: screen;
-            constrain: y;
+            constrain: none inside;
+            color: $foreground;
+            border: tall $border-blurred;
+            background: $surface;
+            &:focus {
+                background-tint: $foreground 5%;
+            }
+            & > .option-list--option {
+                padding: 0 1;
+            }
         }
 
-        &:focus > SelectCurrent {
-            border: tall $accent;
+        &.-expanded {
+            .down-arrow {
+                display: none;
+            }
+
+            .up-arrow {
+                display: block;
+            }
+
+            & > SelectOverlay {
+                display: block;
+            }
         }
 
-        .up-arrow {
-            display: none;
-        }
-
-        &.-expanded .down-arrow {
-            display: none;
-        }
-
-        &.-expanded .up-arrow {
-            display: block;
-        }
-
-        &.-expanded > SelectOverlay {
-            display: block;
-        }
-
-        &.-expanded > SelectCurrent {
-            border: tall $accent;
-        }
     }
 
     """
@@ -296,6 +301,7 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
         id: str | None = None,
         classes: str | None = None,
         disabled: bool = False,
+        tooltip: RenderableType | None = None,
     ):
         """Initialize the Select control.
 
@@ -313,6 +319,7 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
             id: The ID of the control in the DOM.
             classes: The CSS classes of the control.
             disabled: Whether the control is disabled or not.
+            tooltip: Optional tooltip.
 
         Raises:
             EmptySelectError: If no options are provided and `allow_blank` is `False`.
@@ -322,6 +329,8 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
         self.prompt = prompt
         self._value = value
         self._setup_variables_for_options(options)
+        if tooltip is not None:
+            self.tooltip = tooltip
 
     @classmethod
     def from_values(
@@ -487,7 +496,11 @@ class Select(Generic[SelectType], Vertical, can_focus=True):
 
     def _watch_expanded(self, expanded: bool) -> None:
         """Display or hide overlay."""
-        overlay = self.query_one(SelectOverlay)
+        try:
+            overlay = self.query_one(SelectOverlay)
+        except NoMatches:
+            # The widget has likely been removed
+            return
         self.set_class(expanded, "-expanded")
         if expanded:
             overlay.focus()
