@@ -11,12 +11,12 @@ from rich.style import Style
 from rich.text import Text, TextType
 from typing_extensions import Self
 
-from .. import events
-from ..binding import Binding
-from ..messages import Message
-from ..strip import Strip
-from ._option_list import NewOptionListContent, Option, OptionList
-from ._toggle_button import ToggleButton
+from textual import events
+from textual.binding import Binding
+from textual.messages import Message
+from textual.strip import Strip
+from textual.widgets._option_list import NewOptionListContent, Option, OptionList
+from textual.widgets._toggle_button import ToggleButton
 
 SelectionType = TypeVar("SelectionType")
 """The type for the value of a [`Selection`][textual.widgets.selection_list.Selection] in a [`SelectionList`][textual.widgets.SelectionList]"""
@@ -71,7 +71,7 @@ class Selection(Generic[SelectionType], Option):
 class SelectionList(Generic[SelectionType], OptionList):
     """A vertical selection list that allows making multiple selections."""
 
-    BINDINGS = [Binding("space", "select")]
+    BINDINGS = [Binding("space", "select", "Toggle option", show=False)]
     """
     | Key(s) | Description |
     | :- | :- |
@@ -96,62 +96,27 @@ class SelectionList(Generic[SelectionType], OptionList):
     DEFAULT_CSS = """
     SelectionList {
         height: auto;
-    }
+        
+        & > .selection-list--button {
+            color: $panel-darken-2;
+            background: $panel;
+        }
 
-    SelectionList:light:focus > .selection-list--button-selected {
-        color: $primary;
-    }
+        & > .selection-list--button-highlighted {
+            color: $panel-darken-2;
+            background: $panel;
+        }
 
-    SelectionList:light > .selection-list--button-selected-highlighted {
-        color: $primary;
-    }
+        & > .selection-list--button-selected {
+            color: $text-success;
+            background: $panel;
+        }
 
-    SelectionList:light:focus > .selection-list--button-selected-highlighted {
-        color: $primary;
-    }
+        & > .selection-list--button-selected-highlighted {
+            color: $text-success;
+            background: $panel;
+        }
 
-    SelectionList > .selection-list--button {
-        text-style: bold;
-        background: $foreground 15%;
-    }
-
-    SelectionList:focus > .selection-list--button {
-        text-style: bold;
-        background: $foreground 25%;
-    }
-
-    SelectionList > .selection-list--button-highlighted {
-        text-style: bold;
-        background: $foreground 15%;
-    }
-
-    SelectionList:focus > .selection-list--button-highlighted {
-        text-style: bold;
-        background: $foreground 25%;
-    }
-
-    SelectionList > .selection-list--button-selected {
-        text-style: bold;
-        color: $success;
-        background: $foreground 15%;
-    }
-
-    SelectionList:focus > .selection-list--button-selected {
-        text-style: bold;
-        color: $success;
-        background: $foreground 25%;
-    }
-
-    SelectionList > .selection-list--button-selected-highlighted {
-        text-style: bold;
-        color: $success;
-        background: $foreground 15%;
-    }
-
-    SelectionList:focus > .selection-list--button-selected-highlighted {
-        text-style: bold;
-        color: $success;
-        background: $foreground 25%;
     }
     """
 
@@ -202,6 +167,16 @@ class SelectionList(Generic[SelectionType], OptionList):
     class SelectionToggled(SelectionMessage[MessageSelectionType]):
         """Message sent when a selection is toggled.
 
+        This is only sent when the value is *explicitly* toggled e.g.
+        via `toggle` or `toggle_all`, or via user interaction.
+        If you programmatically set a value to be selected, this message will
+        not be sent, even if it happens to be the opposite of what was
+        originally selected (i.e. setting a True to a False or vice-versa).
+
+        Since this message indicates a toggle occurring at a per-option level,
+        a message will be sent for each option that is toggled, even when a
+        bulk action is performed (e.g. via `toggle_all`).
+
         Can be handled using `on_selection_list_selection_toggled` in a subclass of
         [`SelectionList`][textual.widgets.SelectionList] or in a parent node in the DOM.
         """
@@ -210,6 +185,13 @@ class SelectionList(Generic[SelectionType], OptionList):
     class SelectedChanged(Generic[MessageSelectionType], Message):
         """Message sent when the collection of selected values changes.
 
+        This is sent regardless of whether the change occurred via user interaction
+        or programmatically the the `SelectionList` API.
+
+        When a bulk change occurs, such as through `select_all` or `deselect_all`,
+        only a single `SelectedChanged` message will be sent (rather than one per
+        option).
+
         Can be handled using `on_selection_list_selected_changed` in a subclass of
         [`SelectionList`][textual.widgets.SelectionList] or in a parent node in the DOM.
         """
@@ -316,10 +298,10 @@ class SelectionList(Generic[SelectionType], OptionList):
         # Keep track of if anything changed.
         changed = False
 
-        # Next we run through everything and apply the change, preventing
-        # the toggled and changed messages because the caller really isn't
-        # going to be expecting a message storm from this.
-        with self.prevent(self.SelectedChanged, self.SelectionToggled):
+        # Apply the state change function to all options.
+        # We don't send a SelectedChanged for each option, and instead
+        # send a single SelectedChanged afterwards if any values change.
+        with self.prevent(self.SelectedChanged):
             for selection in self._options:
                 changed = (
                     state_change(cast(Selection[SelectionType], selection).value)
@@ -559,10 +541,10 @@ class SelectionList(Generic[SelectionType], OptionList):
 
         # If the button is in the unselected state, we're going to do a bit
         # of a switcharound to make it look like it's a "cutout".
-        if selection.value not in self._selected:
-            button_style += Style.from_color(
-                self.background_colors[1].rich_color, button_style.bgcolor
-            )
+        # if selection.value not in self._selected:
+        #     button_style += Style.from_color(
+        #         self.background_colors[1].rich_color, button_style.bgcolor
+        #     )
 
         # Build the style for the side characters. Note that this is
         # sensitive to the type of character used, so pay attention to
@@ -646,6 +628,11 @@ class SelectionList(Generic[SelectionType], OptionList):
         option = self.get_option_at_index(index)
         self._deselect(option.value)
         del self._values[option.value]
+        # Decrement index of options after the one we just removed.
+        self._values = {
+            option_value: option_index - 1 if option_index > index else option_index
+            for option_value, option_index in self._values.items()
+        }
         return super()._remove_option(index)
 
     def add_options(
