@@ -9,14 +9,15 @@ from rich.repr import Result
 from rich.text import Text, TextType
 from typing_extensions import Final
 
-from ..app import ComposeResult
-from ..await_complete import AwaitComplete
-from ..css.query import NoMatches
-from ..message import Message
-from ..reactive import reactive
-from ..widget import Widget
-from ._content_switcher import ContentSwitcher
-from ._tabs import Tab, Tabs
+from textual import events
+from textual.app import ComposeResult
+from textual.await_complete import AwaitComplete
+from textual.css.query import NoMatches
+from textual.message import Message
+from textual.reactive import reactive
+from textual.widget import Widget
+from textual.widgets._content_switcher import ContentSwitcher
+from textual.widgets._tabs import Tab, Tabs
 
 __all__ = [
     "ContentTab",
@@ -168,7 +169,6 @@ class TabPane(Widget):
     DEFAULT_CSS = """
     TabPane {
         height: auto;
-        padding: 1 2;
     }
     """
 
@@ -196,6 +196,10 @@ class TabPane(Widget):
     class Enabled(TabPaneMessage):
         """Sent when a tab pane is enabled via its reactive `disabled`."""
 
+    @dataclass
+    class Focused(TabPaneMessage):
+        """Sent when a child widget is focused."""
+
     def __init__(
         self,
         title: TextType,
@@ -224,10 +228,15 @@ class TabPane(Widget):
         """Notify the parent `TabbedContent` that a tab pane was enabled/disabled."""
         self.post_message(self.Disabled(self) if disabled else self.Enabled(self))
 
+    def _on_descendant_focus(self, event: events.DescendantFocus):
+        """Tell TabbedContent parent something is focused in this pane."""
+        self.post_message(self.Focused(self))
+
 
 class TabbedContent(Widget):
     """A container with associated tabs to toggle content visibility."""
 
+    ALLOW_MAXIMIZE = True
     DEFAULT_CSS = """
     TabbedContent {
         height: auto;
@@ -315,10 +324,10 @@ class TabbedContent(Widget):
         Args:
             *titles: Positional argument will be used as title.
             initial: The id of the initial tab, or empty string to select the first tab.
-            name: The name of the button.
-            id: The ID of the button in the DOM.
-            classes: The CSS classes of the button.
-            disabled: Whether the button is disabled or not.
+            name: The name of the tabbed content.
+            id: The ID of the tabbed content in the DOM.
+            classes: The CSS classes of the tabbed content.
+            disabled: Whether the tabbed content is disabled or not.
         """
         self.titles = [self.render_str(title) for title in titles]
         self._tab_content: list[Widget] = []
@@ -453,10 +462,7 @@ class TabbedContent(Widget):
             # other means; so allow that to be a no-op.
             pass
 
-        async def _remove_content() -> None:
-            await gather(*removal_awaitables)
-
-        return AwaitComplete(_remove_content())
+        return AwaitComplete(*removal_awaitables)
 
     def clear_panes(self) -> AwaitComplete:
         """Remove all the panes in the tabbed content.
@@ -507,6 +513,12 @@ class TabbedContent(Widget):
                 )
             )
 
+    def _on_tab_pane_focused(self, event: TabPane.Focused) -> None:
+        """One of the panes contains a widget that was programmatically focused."""
+        event.stop()
+        if event.tab_pane.id is not None:
+            self.active = event.tab_pane.id
+
     def _on_tabs_cleared(self, event: Tabs.Cleared) -> None:
         """Called when there are no active tabs. The tabs may have been cleared,
         or they may all be hidden."""
